pub struct HookTrigger {
pub paths: Vec<String>,
pub dirs: Vec<String>,
pub operation: Vec<String>,
pub packages: Vec<String>,
}Expand description
Defines when a global hook should be triggered.
Fields
paths: Vec<String>Glob patterns for file paths that trigger the hook.
dirs: Vec<String>Directories that trigger the hook if any file within them is modified.
operation: Vec<String>The operation types (e.g. “install”, “upgrade”, “remove”) that trigger the hook.
packages: Vec<String>Specific package names that trigger the hook when modified.